==> bpmn-js-0.10.3.jar: META-INF/resources/webjars/bpmn-js/0.10.3/test/spec/features/modeling/DeleteParticipantSpec.js <==
'use strict';

var TestHelper = require('../../../TestHelper');

/* global bootstrapModeler, inject */


var modelingModule = require('../../../../lib/features/modeling'),
    coreModule = require('../../../../lib/core');


describe('features/modeling - delete participant', function() {

  var testModules = [ coreModule, modelingModule ];


  describe('last remaining', function() {

    describe('should transform diagram into process diagram', function() {

      var processDiagramXML = require('../../../fixtures/bpmn/collaboration/collaboration-empty-participant.bpmn');

      beforeEach(bootstrapModeler(processDiagramXML, { modules: testModules }));


      it('execute', inject(function(modeling, elementRegistry, canvas) {

        // given
        var participantShape = elementRegistry.get('_Participant_2'),
            participant = participantShape.businessObject,
            participantDi = participant.di,
            process = participant.processRef,
            collaborationElement = participantShape.parent,
            collaboration = collaborationElement.businessObject,
            diPlane = collaboration.di,
            bpmnDefinitions = collaboration.$parent;

        // when
        modeling.removeShape(participantShape);

        // then
        expect(participant.$parent).toBeFalsy();

        var newRootShape = canvas.getRootElement(),
            newRootBusinessObject = newRootShape.businessObject;

        expect(newRootBusinessObject.$instanceOf('bpmn:Process')).toBe(true);

        // collaboration DI is unwired
        expect(participantDi.$parent).toBeFalsy();
        expect(collaboration.di).toBeFalsy();

        expect(bpmnDefinitions.rootElements).not.toContain(process);
        expect(bpmnDefinitions.rootElements).not.toContain(collaboration);

        // process DI is wired
        expect(diPlane.bpmnElement).toBe(newRootBusinessObject);
        expect(newRootBusinessObject.di).toBe(diPlane);

        expect(bpmnDefinitions.rootElements).toContain(newRootBusinessObject);
      }));


      it('undo', inject(function(modeling, elementRegistry, canvas, commandStack) {

        // given
        var participantShape = elementRegistry.get('_Participant_2'),
            participant = participantShape.businessObject,
            originalRootElement = participantShape.parent,
            originalRootElementBo = originalRootElement.businessObject,
            bpmnDefinitions = originalRootElementBo.$parent,
            participantDi = participant.di,
            diPlane = participantDi.$parent;

        modeling.removeShape(participantShape);

        // when
        commandStack.undo();

        // then
        expect(participant.$parent).toBe(originalRootElementBo);
        expect(originalRootElementBo.$parent).toBe(bpmnDefinitions);

        expect(canvas.getRootElement()).toBe(originalRootElement);

        // di is unwired
        expect(participantDi.$parent).toBe(originalRootElementBo.di);

        // new di is wired
        expect(diPlane.bpmnElement).toBe(originalRootElementBo);
      }));

    });

  });

});

==> bpmn-js-0.16.0.jar: META-INF/resources/webjars/bpmn-js/0.16.0/test/spec/features/modeling/DeleteParticipantSpec.js <==
'use strict';

require('../../../TestHelper');

/* global bootstrapModeler, inject */


var modelingModule = require('../../../../lib/features/modeling'),
    coreModule = require('../../../../lib/core');


describe('features/modeling - delete participant', function() {

  var testModules = [ coreModule, modelingModule ];


  describe('last remaining', function() {

    describe('should transform diagram into process diagram', function() {

      var processDiagramXML = require('../../../fixtures/bpmn/collaboration/collaboration-empty-participant.bpmn');

      beforeEach(bootstrapModeler(processDiagramXML, { modules: testModules }));


      it('execute', inject(function(modeling, elementRegistry, canvas) {

        // given
        var participantShape = elementRegistry.get('_Participant_2'),
            participant = participantShape.businessObject,
            participantDi = participant.di,
            process = participant.processRef,
            collaborationElement = participantShape.parent,
            collaboration = collaborationElement.businessObject,
            diPlane = collaboration.di,
            bpmnDefinitions = collaboration.$parent;

        // when
        modeling.removeShape(participantShape);

        // then
        expect(participant.$parent).to.not.be.ok;

        var newRootShape = canvas.getRootElement(),
            newRootBusinessObject = newRootShape.businessObject;

        expect(newRootBusinessObject.$instanceOf('bpmn:Process')).to.be.true;

        // collaboration DI is unwired
        expect(participantDi.$parent).to.not.be.ok;
        expect(collaboration.di).to.not.be.ok;

        expect(bpmnDefinitions.rootElements).to.not.include(process);
        expect(bpmnDefinitions.rootElements).to.not.include(collaboration);

        // process DI is wired
        expect(diPlane.bpmnElement).to.eql(newRootBusinessObject);
        expect(newRootBusinessObject.di).to.eql(diPlane);

        expect(bpmnDefinitions.rootElements).to.include(newRootBusinessObject);
      }));


      it('undo', inject(function(modeling, elementRegistry, canvas, commandStack) {

        // given
        var participantShape = elementRegistry.get('_Participant_2'),
            participant = participantShape.businessObject,
            originalRootElement = participantShape.parent,
            originalRootElementBo = originalRootElement.businessObject,
            bpmnDefinitions = originalRootElementBo.$parent,
            participantDi = participant.di,
            diPlane = participantDi.$parent;

        modeling.removeShape(participantShape);

        // when
        commandStack.undo();

        // then
        expect(participant.$parent).to.eql(originalRootElementBo);
        expect(originalRootElementBo.$parent).to.eql(bpmnDefinitions);

        expect(canvas.getRootElement()).to.eql(originalRootElement);

        // di is unwired
        expect(participantDi.$parent).to.eql(originalRootElementBo.di);

        // new di is wired
        expect(diPlane.bpmnElement).to.eql(originalRootElementBo);
      }));

    });

  });

});
